==> mill-config-client-1.1.1.tgz: package/src/controller/socket/code.ts <==
#!/usr/bin/env node

import { program } from "commander"
import inquirer from "inquirer"
import { loadYaml } from "../../utils/load-yaml"
import { getLogger } from "../../utils/logging"
import { existsSync, readFileSync } from "fs"
import { resolve, extname, basename } from "path"
import shell from "shelljs"
import { publish, redisHandler } from "../../utils/redis"
/**
 *  将配置结构发送到配置端
 */
const mainCfg = loadYaml("config/main.cfg.yaml")
interface Answer {
  title: string
  treeCode: string
}

export const logger = getLogger()
program
  .option("-f, --file <string> ", "配置文件路径")
program.parse(process.argv)
const opts = program.opts()

if (!opts.file) {
  logger.error("必须指定配置文件地址!")
  shell.exit(1)
}


const filePath = resolve("./", opts.file)

if ([".yaml", ".yml"].findIndex(el => extname(filePath) === el) === -1) {
  logger.error("配置文件必须是yaml格式!")
  shell.exit(1)

}


if (!existsSync(filePath)) {
  logger.error("配置文件不存在!")
  shell.exit(1)
}

const bname = basename(filePath);
logger.info("basename is :" + bname)

const answer: Answer = {
  title: bname,
  treeCode: readFileSync(filePath).toString()
}


redisHandler(clt => {

  // 设置配置文件内容到redis
  clt.hset("config-struct", "title", answer.title
    , "treeCode", answer.treeCode, num => {
      logger.info(`publish ${mainCfg.redis.channel} code-struct...`)
      clt.publish(mainCfg.redis.channel, "code-struct") // 推送代码结构
      clt.quit()
    })

})
// socket.emit("code", JSON.stringify(answer))
logger.info("emit-code success")

==> mill-config-client-1.1.6.tgz: package/src/controller/socket/code.ts <==
#!/usr/bin/env node

import { program } from "commander"
import inquirer from "inquirer"
import { loadYaml } from "../../utils/load-yaml"
import { getLogger } from "../../utils/logging"
import { existsSync, readFileSync } from "fs"
import { resolve, extname, basename } from "path"
import shell from "shelljs"
// import { publish, redisHandler } from "../../utils/redis"
/**
 *  将配置结构发送到配置端
 */
const mainCfg = loadYaml("config/main.cfg.yaml")
interface Answer {
  title: string
  treeCode: string
}

export const logger = getLogger()
program
  .option("-f, --file <string> ", "配置文件路径")
program.parse(process.argv)
const opts = program.opts()

if (!opts.file) {
  logger.error("必须指定配置文件地址!")
  shell.exit(1)
}


const filePath = resolve("./", opts.file)

if ([".yaml", ".yml"].findIndex(el => extname(filePath) === el) === -1) {
  logger.error("配置文件必须是yaml格式!")
  shell.exit(1)

}


if (!existsSync(filePath)) {
  logger.error("配置文件不存在!")
  shell.exit(1)
}

const bname = basename(filePath);
logger.info("basename is :" + bname)

const answer: Answer = {
  title: bname,
  treeCode: readFileSync(filePath).toString()
}


// redisHandler(clt => {

//   // 设置配置文件内容到redis
//   clt.hset("config-struct", "title", answer.title
//     , "treeCode", answer.treeCode, num => {
//       logger.info(`publish ${mainCfg.redis.channel} code-struct...`)
//       clt.publish(mainCfg.redis.channel, "code-struct") // 推送代码结构
//       clt.quit()
//     })

// })
// socket.emit("code", JSON.stringify(answer))
logger.info("emit-code success")
